/******************************************************************************
 * RatingGraphPanel.java - The toolbar ratings graph widget
 * $Id: RatingGraphPanel.java,v 1.3 2009/02/23 09:51:18 dick Exp $
 * 
 * BuckoFIBS - Backgammon by BuckoSoft
 * Copyright 2009 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: RatingGraphPanel.java,v $
 * Revision 1.3  2009/02/23 09:51:18  dick
 * Draw the marker dots at each match.
 *
 * Revision 1.2  2009/02/22 07:06:24  dick
 * Display the ratings text in the panel.
 *
 * Revision 1.1  2009/02/21 17:34:56  dick
 * The toolbar ratings graph widget.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is BuckoFIBS, <http://www.buckosoft.com/BuckoFIBS/>.
 * The Initial Developer of the Original Code is Dick Balaska and BuckoSoft, Corp.
 * 
 */
package com.buckosoft.fibs.BuckoFIBS.gui;

import javax.swing.JPanel;
import java.awt.Dimension;
import java.awt.Color;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Graphics;

/** The toolbar ratings graph widget
 * @author Dick Balaska
 * @since 2009/02/20
 * @version $Revision: 1.3 $ <br> $Date: 2009/02/23 09:51:18 $
 * @see <a href="http://cvs.buckosoft.com/Projects/BuckoFIBS/BuckoFIBS/src/com/buckosoft/fibs/BuckoFIBS/gui/RatingGraphPanel.java">cvs RatingGraphPanel.java</a>
 */
public class RatingGraphPanel extends JPanel {
	private static final long serialVersionUID = 1L;
	private	Font	font = new Font("Arial", Font.PLAIN, 10);
	
	protected class Specs {
		int w;
		int h;
	}
	private	Specs bs = new Specs();  //  @jve:decl-index=0:

	private	double data[] = new double[] { 1500.0, 1503.0, 1505.0 };
	private	int	xpoints[] = new int[data.length];
	private	int	ypoints[] = new int[data.length];

	/** Create a new RatingGraphPanel 
	 */
	public RatingGraphPanel() {
		super();
		initialize();
	}

	/** Set the data points to use in the graph. <br>
	 * This is an array of ratings. <br>
	 * Setting the data causes the graph to redraw itself.
	 * @param data
	 */
	public void setData(double[] data) {
		this.data = data;
		xpoints = new int[data.length];
		ypoints = new int[data.length];
		this.repaint();
	}

	/**
	 * This method initializes this
	 * 
	 */
	private void initialize() {
        this.setSize(new Dimension(216, 61));
	}

	/** Override JComponent's paint(Graphics)
	 * @param g The Graphics from Swing
	 */
	public void paint(Graphics g) {
		super.paint(g);
		
		int i;
		int	x,y;
		double high, low, range;
		double d;
		bs.w = this.getWidth();
		bs.h = this.getHeight();
		g.setColor(Color.black);
		g.fillRect(0, 0, bs.w, bs.h);
		
		if (data == null || data.length == 0)
			return;
		g.setColor(Color.green);
		if (data.length == 1) {
			g.drawLine(0, bs.h/2, bs.w, bs.h/2);
			low = -100000;
			high = 20000;
			range = high - low;
		} else {
			low = data[0];
			high = data[1];
			for (i=0; i<data.length; i++) {
				if (low > data[i])
					low = data[i];
				if (high < data[i])
					high = data[i];
			}
			range = high - low;
			for (i=0; i<data.length; i++) {
				//double d;
				if (i == 0)
					xpoints[i] = 0;
				else
					xpoints[i] = i * bs.w / (data.length-1);
				ypoints[i] = (int)(bs.h-((data[i]-low)*bs.h / range));
			}
			g.drawPolyline(xpoints, ypoints, xpoints.length);
			
			g.setColor(Color.white);
			g.setFont(font);
			FontMetrics fm = g.getFontMetrics();
			String s = "" + low; 
			//int sw = fm.stringWidth(s);
			x = 0;
			y = bs.h-1; 
			g.drawString(s, x, y);
			s = "" + high;
			y = 0 + fm.getAscent()-1;
			g.drawString(s, x, y);
		}
		g.setColor(Color.white);
		g.setFont(font);
		FontMetrics fm = g.getFontMetrics();
		d = data[data.length-1];
		String s = "" + d;
		int sw = fm.stringWidth(s);
		x = bs.w - sw;
		double mid = low + range/2;
		if (d > mid)
			y = bs.h*3/4 + fm.getAscent()/2;
		else
			y = bs.h*1/4 + fm.getAscent()/2;
		g.drawString(s, x, y);
		
		for (i=0; i<data.length; i++) {
			Color c = Color.green;
			if (i>0 && data[i] < data[i-1])
				c = Color.red;
			g.setColor(c);
			g.drawRect(xpoints[i]-1, ypoints[i]-1, 3, 3);
		}

	}	

}  //  @jve:decl-index=0:visual-constraint="10,10"
