/******************************************************************************
 * PlayerNameRenderer.java - Draw the player name and any icons in the player table
 * $Id: PlayerNameRenderer.java,v 1.3 2009/02/14 15:46:36 dick Exp $
 * 
 * BuckoFIBS - Backgammon by BuckoSoft
 * Copyright 2009 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: PlayerNameRenderer.java,v $
 * Revision 1.3  2009/02/14 15:46:36  dick
 * BuckoFIBS is released under the GNU license.
 *
 * Revision 1.2  2009/02/01 21:29:48  dick
 * Draw MissManners and SavedGames tooltips.
 *
 * Revision 1.1  2009/02/01 09:01:01  dick
 * Draw the player name and any icons in the player table.
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is BuckoFIBS, <http://www.buckosoft.com/BuckoFIBS/>.
 * The Initial Developer of the Original Code is Dick Balaska and BuckoSoft, Corp.
 * 
 */
package com.buckosoft.fibs.BuckoFIBS.gui.playerList;

import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTable;
import javax.swing.table.TableCellRenderer;

import com.buckosoft.fibs.domain.Player;
import java.awt.Font;

/** Draw the player name and any icons in the player table
 * @author Dick Balaska
 * @since 2009/02/01
 * @version $Revision: 1.3 $ <br> $Date: 2009/02/14 15:46:36 $
 * @see <a href="http://cvs.buckosoft.com/Projects/BuckoFIBS/BuckoFIBS/src/com/buckosoft/fibs/BuckoFIBS/gui/inviterList/PlayerNameRenderer.java">cvs PlayerNameRenderer.java</a>
 */
public class PlayerNameRenderer extends JPanel implements TableCellRenderer {
	private static final long serialVersionUID = 1L;
	private	Color	selectedBackgroundColor;  //  @jve:decl-index=0:
	private JLabel jLabel = null;
	private JLabel jLabelIcon0 = null;
	private JLabel jLabelIcon1 = null;
	private	ImageIcon	warningIcon = new ImageIcon(getClass().getResource("/g/caution.png"));
	private	ImageIcon	docWarnIcon = new ImageIcon(getClass().getResource("/g/docwarn.png"));

	/**
	 * This method initializes 
	 * 
	 */
	public PlayerNameRenderer() {
		super();
		initialize();
	}

	/**
	 * This method initializes this
	 * 
	 */
	private void initialize() {
        GridBagConstraints gridBagConstraints2 = new GridBagConstraints();
        gridBagConstraints2.insets = new Insets(0, 0, 0, 0);
        gridBagConstraints2.gridx = 1;
        gridBagConstraints2.gridy = 0;
        gridBagConstraints2.anchor = GridBagConstraints.EAST;
        gridBagConstraints2.weightx = 0.2;
        gridBagConstraints2.gridheight = 1;
        GridBagConstraints gridBagConstraints1 = new GridBagConstraints();
        gridBagConstraints1.insets = new Insets(0, 0, 0, 0);
        gridBagConstraints1.gridx = 2;
        gridBagConstraints1.gridy = 0;
        gridBagConstraints1.anchor = GridBagConstraints.EAST;
        gridBagConstraints1.weightx = 0.2;
        gridBagConstraints1.gridheight = 1;
        GridBagConstraints gridBagConstraints = new GridBagConstraints();
        gridBagConstraints.insets = new Insets(0, 0, 0, 0);
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.anchor = GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.2;
        gridBagConstraints.gridheight = 1;
        jLabelIcon0 = new JLabel();
		jLabelIcon0.setIcon(warningIcon);
        jLabelIcon1 = new JLabel();
		jLabelIcon1.setIcon(docWarnIcon);
//        jLabelIcon.setText("");
        jLabel = new JLabel();
        jLabel.setText("JLabel");
        jLabel.setFont(new Font("Dialog", Font.PLAIN, 12));
        this.setLayout(new GridBagLayout());
        this.setSize(new Dimension(79, 22));
        this.add(jLabel, gridBagConstraints);
        this.add(jLabelIcon0, gridBagConstraints1);
        this.add(jLabelIcon1, gridBagConstraints2);
			
	}

	public void setSelectedBackground(Color color) {
		selectedBackgroundColor = color;
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableCellRenderer#getTableCellRendererComponent(javax.swing.JTable, java.lang.Object, boolean, boolean, int, int)
	 */
	@Override
	public Component getTableCellRendererComponent(JTable table, Object value,
			boolean isSelected, boolean hasFocus, int row, int column) {
		Player p = (Player)value;
		this.setOpaque(true);
		this.jLabel.setOpaque(true);
		if (isSelected) {
			this.setBackground(selectedBackgroundColor);
			this.jLabel.setBackground(selectedBackgroundColor);
		} else {
			this.setBackground(Color.white);
			this.jLabel.setBackground(Color.white);
		}
		this.jLabel.setText(p.getName());
		this.jLabel.setOpaque(true);
		String tt = "";
		if (p.getBfStatus() != null && p.getBfStatus().length() > 0) {
			this.jLabelIcon0.setVisible(true);
			tt += p.getBfStatus();
		} else {
			this.jLabelIcon0.setVisible(false);
			//this.setToolTipText(null);
		}
		if (p.getMissManners() != null) {
			this.jLabelIcon0.setVisible(true);
			//this.setToolTipText(p.getMissManners());
			if (tt.length() > 0)
				tt += "\r\n";
			tt += p.getMissManners();
		} else {
			this.jLabelIcon0.setVisible(false);
			//this.setToolTipText(null);
		}
		if (p.getSavedMatch() != null) {
			this.jLabelIcon1.setVisible(true);
			//this.setToolTipText(p.getSavedMatch());
			if (tt.length() > 0)
				tt += "\r\n";
			tt += p.getSavedMatch();
		} else {
			this.jLabelIcon1.setVisible(false);
			//this.setToolTipText(null);
		}
		this.setToolTipText(tt.length() > 1 ? tt : null);
		return this;
	}

}  //  @jve:decl-index=0:visual-constraint="10,10"
